@@ -394,11 +394,14 @@ class Mobot:
         """
         Non-blocking version of move(). See move() for more details
         """
-        angles = self.getJointAngles()
-        self.moveToNB(  angle1+angles[0], 
-                        angle2+angles[1], 
-                        angle3+angles[2], 
-                        angle4+angles[3])
+        angle1 = _util.deg2rad(angle1)
+        angle2 = _util.deg2rad(angle2)
+        angle3 = _util.deg2rad(angle3)
+        angle4 = _util.deg2rad(angle4)
+        buf = bytearray([barobo.BaroboCtx.CMD_MOVE_MOTORS, 0x13])
+        buf += bytearray(struct.pack('<4f', angle1, angle2, angle3, angle4))
+        buf += bytearray([0x00])
+        self._transactMessage(buf)
 
     def moveContinuous(self, dir1, dir2, dir3, dir4):
         """
@@ -642,7 +645,7 @@ class Mobot:
         buf +=bytearray([0x00])
         self._transactMessage(buf)
 
-    def setMovementState(self, state1, state2, state3, state4):
+    def setMovementState(self, state1, state2, state3, state4, time=-1):
         """
         Set the movement state for all three motors.
 
@@ -667,10 +670,12 @@ class Mobot:
             elif state3 == barobo.ROBOT_NEGATIVE:
                 state3 = barobo.ROBOT_BACKWARD
         states = [state1, state2, state3, state4]
+        if time > 0:
+            time = time * 1000
         buf = bytearray([barobo.BaroboCtx.CMD_TIMEDACTION, 0, 0x07])
         for state in states:
-            buf += bytearray([state1, barobo.ROBOT_HOLD])
-            buf += bytearray(struct.pack('<i', -1))
+            buf += bytearray([state, barobo.ROBOT_HOLD])
+            buf += bytearray(struct.pack('<i', time))
         buf += bytearray([0x00])
         buf[1] = len(buf)
         self._transactMessage(buf)
